@@ -246,7 +246,11 @@ public class SequenceAnalyser extends Thread {
 	 	
 	 	Runtime runtime = Runtime.getRuntime();      
 	 	String command = null;
-	 	if(Logol.getSuffixTool()==1) {
+	 	switch(Logol.getSuffixTool()) {
+	 	case 0:
+	 		command = "ruby "+Treatment.installPath+System.getProperty(Constants.FILESEPARATORPROPERTY)+"tools"+System.getProperty(Constants.FILESEPARATORPROPERTY)+"logolIndex.rb --index "+outputFile+" --out "+outputFile+".index";
+	 		break;
+	 	case 1:
 		 	command = suffixPath+"mkvtree -db "+outputFile+" -pl "+minTreeIndex+" -allout -v -indexname "+outputFile;
 		 	if(lv_type.equals("dna")) {
 		 		// Use specific map file in index creation
@@ -255,33 +259,41 @@ public class SequenceAnalyser extends Thread {
 		 	else {
 		 		command+=" -"+lv_type;
 		 	}
+		 	break;
+	 	case 2:
+	 		logger.debug("no index creation required");
+	 		command = null;
+	 		break;
+	 	default:
+	 		command = null;
+	 		break;
 	 	}
-	 	else {
-	 		command = "ruby "+Treatment.installPath+System.getProperty(Constants.FILESEPARATORPROPERTY)+"tools"+System.getProperty(Constants.FILESEPARATORPROPERTY)+"logolIndex.rb --index "+outputFile+" --out "+outputFile+".index";
-	 	}
-	 	logger.debug("Tree creation command: "+command);
-        Process mkvtree = runtime.exec(command);
-        try {
-        	PrintStream os = new PrintStream(mkvtree.getOutputStream());
-        	os.println("");
-        	os.flush();
-        	        	
-        	StreamGobbler s1 = new StreamGobbler ("stdin", mkvtree.getInputStream ());
-        	StreamGobbler s2 = new StreamGobbler ("stderr", mkvtree.getErrorStream ());
-        	s1.start ();
-        	s2.start ();
-        	int status = mkvtree.waitFor();
-        	if (status>0) {
-        		logger.error("An error occured while creating index tree for command: "+command);
-        	}
-        	else {
-        		logger.debug("Tree created for "+outputFile);
-        	}
-			os.close();
 
-		} catch (InterruptedException e) {
-			logger.error("could not create Tree "+ e.getMessage());
-		} 
+	 	if(command!=null) {
+	 		logger.debug("Tree creation command: "+command);
+	 		Process mkvtree = runtime.exec(command);
+	 		try {
+	 			PrintStream os = new PrintStream(mkvtree.getOutputStream());
+	 			os.println("");
+	 			os.flush();
+        	        	
+	 			StreamGobbler s1 = new StreamGobbler ("stdin", mkvtree.getInputStream ());
+	 			StreamGobbler s2 = new StreamGobbler ("stderr", mkvtree.getErrorStream ());
+	 			s1.start ();
+	 			s2.start ();
+	 			int status = mkvtree.waitFor();
+	 			if (status>0) {
+	 				logger.error("An error occured while creating index tree for command: "+command);
+	 			}
+	 			else {
+	 				logger.debug("Tree created for "+outputFile);
+	 			}
+	 			os.close();
+
+	 		} catch (InterruptedException e) {
+	 			logger.error("could not create Tree "+ e.getMessage());
+	 		}
+	 	}
 		
 	}
 
