@@ -76,7 +76,7 @@ class StreamGobbler implements Runnable {
 
 	private static final Logger logger = Logger.getLogger(StreamGobbler.class);
 
-	
+
 	public StreamGobbler (String name, InputStream is) {
 	this.name = name;
 	this.is = is;
@@ -114,19 +114,19 @@ class StreamGobbler implements Runnable {
 
 
 class SubSequence {
-	
+
 	public String name=null;
 	public int wholeLength=0;
 	public int offset=0;
 	public int sequenceID=1;
 	public int start=0;
-	public int length=0;	
+	public int length=0;
 	public int maxMatchStart=0;
-	
+
 	public SubSequence() {
-		
+
 	}
-	
+
 }
 
 
@@ -143,92 +143,92 @@ class SubSequence {
  *          18/02/10 Fix 1576 Change email subject
  *			21/07/10 Fix 1660 OutofMemory issue with Biojava
  *			31/07/12 Fix If out option is used, used outfilename in mail
- *          
+ *
  * Known issues in DMR mode: configuration file and model do not support relative path, only sequence path does support it.
  * This issue is due to the fact that when job is transfered on a node, the path is not the same and is system dependent. The software does not change this directory (TODO)
- *          
+ *
  */
 public class Dispatch {
 
 	private static final Logger logger = Logger.getLogger(org.irisa.genouest.logol.dispatcher.Dispatch.class);
-	
+
 	private static final String FILESEPARATORPROPERTY = "file.separator";
-	
+
 	private static final int LOCAL=0;
 	private static final int SGE=1;
-	
+
 	private static int type = LOCAL;
-	
+
 	private static String bank="";
-	
+
 	private static String configFile="";
-	
+
 	private static int format=1; // FASTADNA, 2 = RNA , 3 = PROTEIN
-	
+
 	private static String workDir=".";
-	
+
 	private static JobManager jobmngr = (JobManager) new LocalJobManager();;
-	
+
 	private static String jobArgs="";
-	
+
 	private static boolean isContig=false;
-	
+
 	private static String installDir = null;
-	
+
 	private static String guid=null;
-	
+
 	private static boolean noclean=false;
-	
+
 	private static String email=null;
-	
+
 	private static PropertiesConfiguration config=null;
-	
+
 	private static final String mailTemplatePath = "prolog/mail.tpl";
-	
+
 	/**
 	 * Number of processors on computer when inn local mode
 	 */
 	private static int nbproc = 1;
-	
+
 	/**
 	 * Max number of jobs to run in parallel for clusters. 0 is no limit.
 	 */
 	private static int nbjobs=0;
-	
+
 	private static String grammar=null;
 	private static String model=null;
-	
+
 	private static int maxMatchSize=0;
 	private static int minSplitSize=0;
-	
+
 	private static int maxSolutions=0;
-	
+
 	private static boolean noClean=false;
-	
+
 	private static String fromMail="do.not.reply";
-	
+
 	private static String zipFileName=null;
-	
+
 	private static boolean forceSplittingUsage = false;
-	
+
 	private static boolean convert2fasta=false;
-	
+
 	private static boolean convert2gff=false;
-	
+
 	/**
 	 * Entry point
 	 * @param args Arguments with bank, config file...
-	 * @throws IOException 
-	 * @throws Exception 
+	 * @throws IOException
+	 * @throws Exception
 	 */
-	public static void main(String[] args) throws IOException {			
-		
+	public static void main(String[] args) throws IOException {
+
 		Options options = new Options();
 
 		 // add command line options
 		 options.addOption("v",false,"get version");
-		 options.addOption("h",false,"get usage");		
-		
+		 options.addOption("h",false,"get usage");
+
 		 options.addOption("s", true, "sequence database");
 		 options.addOption("sge", false, "use SGE");
 		 options.addOption("local", false, "use local system");
@@ -238,29 +238,29 @@ public class Dispatch {
 		 options.addOption("conf", true, "configuration file");
 		 options.addOption("contig", false, "set the bank as contig sequences");
 		 options.addOption("guid", true, "unique identifier for the query");
-		 options.addOption("noclean", false, "Do not delete created files after treatment");	
-		 options.addOption("email", true, "Email address to send result availability info");	
+		 options.addOption("noclean", false, "Do not delete created files after treatment");
+		 options.addOption("email", true, "Email address to send result availability info");
 		 options.addOption("g", true, "grammar file to analyse");
-		 options.addOption("max", true, "maximum returned solutions");		 
+		 options.addOption("max", true, "maximum returned solutions");
 		 options.addOption("maxres", true, "maximum result size of a match");
 		 options.addOption("maxmatchsize", true, "maximum size of a match");
 		 options.addOption("m", true, "model file to analyse");
-		 options.addOption("all",false,"analyse both directions of the sequence");		 
+		 options.addOption("all",false,"analyse both directions of the sequence");
 		 options.addOption("maxspacer", true, "maximum size of a spacer");
 		 options.addOption("lmax", true, "maximum length of a variable");
 		 options.addOption("lmin", true, "minimum length of a variable");
 		 options.addOption("out", true, "Zip output file name");
 		 //Fix 1365
 		 options.addOption("enabledups", false, "enable duplicate result matches. By default only keep singletons");
-		 
-		 // To support logol options		 			 		 		 
-		 options.addOption("output", true, "output file name, must be unique");		 
-		 options.addOption("forcesplit", false, "Force the sequence splitting according to parameters and whatever is the number of model used in grammar");		 
+
+		 // To support logol options
+		 options.addOption("output", true, "output file name, must be unique");
+		 options.addOption("forcesplit", false, "Force the sequence splitting according to parameters and whatever is the number of model used in grammar");
 		 options.addOption("fasta",false,"Add fasta conversion to result archive");
 		 options.addOption("gff",false,"Add gff conversion to result archive");
-		 options.addOption("filter",true,"Type of filter when enabledups is not enabled. Allowed types are exact,local,local0,global.");		 
-		 
-		 
+		 options.addOption("filter",true,"Type of filter when enabledups is not enabled. Allowed types are exact,local,local0,global.");
+
+
 		 CommandLineParser cparser = new PosixParser();
 		 CommandLine cmd=null;
 		try {
@@ -269,24 +269,24 @@ public class Dispatch {
 			displayError(e.getMessage());
 			System.exit(1);
 		}
-		
+
 		System.out.println("For help, use option -h");
 
 		 if(cmd.hasOption("v")) {
-	        	Class<Dispatch> clazz = Dispatch.class; 
+	        	Class<Dispatch> clazz = Dispatch.class;
 	        	String classContainer = clazz.getProtectionDomain().getCodeSource().getLocation().toString();
 	        	URL manifestUrl = new URL("jar:" + classContainer + "!/META-INF/MANIFEST.MF");
 	        	Manifest mf = new Manifest(manifestUrl.openStream());
 	        	Attributes atts = mf.getMainAttributes();
-	        	
-	        	System.out.println("Logol version: "+atts.getValue("Implementation-Version")+"-"+atts.getValue("Implementation-Build"));        		
+
+	        	System.out.println("Logol version: "+atts.getValue("Implementation-Version")+"-"+atts.getValue("Implementation-Build"));
 			 System.exit(0);
 		 }
 		 if(cmd.hasOption("h")) {
 				Options usageOptions = new Options();
 				usageOptions.addOption("v",false,"get version");
 				usageOptions.addOption("h",false,"get usage");
-				usageOptions.addOption("guid", true, "unique identifier for the query");				
+				usageOptions.addOption("guid", true, "unique identifier for the query");
 				usageOptions.addOption("s", true, "sequence database");
 				usageOptions.addOption("g", true, "grammar file to analyse");
 				usageOptions.addOption("m", true, "model file to analyse");
@@ -299,12 +299,12 @@ public class Dispatch {
 				usageOptions.addOption("contig", false, "set the bank as contig sequences");
 				usageOptions.addOption("noclean", false, "Do not delete created files after treatment");
 				usageOptions.addOption("email", true, "Email address to send result availability info");
-				usageOptions.addOption("max", true, "maximum returned solutions");		 
+				usageOptions.addOption("max", true, "maximum returned solutions");
 				usageOptions.addOption("maxres", true, "maximum result size of a match");
 				usageOptions.addOption("maxmatchsize", true, "maximum size of a match");
 				usageOptions.addOption("maxspacer", true, "maximum size of a spacer");
 				usageOptions.addOption("lmax", true, "maximum length of a variable");
-				usageOptions.addOption("lmin", true, "minimum length of a variable");				
+				usageOptions.addOption("lmin", true, "minimum length of a variable");
 				usageOptions.addOption("all",false,"analyse both directions of the sequence");
 				usageOptions.addOption("out", true, "Zip output file name");
 				usageOptions.addOption("enabledups", false, "enable duplicate result matches. By default only keep singletons");
@@ -314,8 +314,8 @@ public class Dispatch {
 				usageOptions.addOption("filter",true,"Type of filter when enabledups is not enabled. Allowed types are exact(default),local,local0,global.");
 				LogolUtils.showUsage(usageOptions);
 				 System.exit(0);
-		 }	
-		 
+		 }
+
 		 if( cmd.hasOption( "guid" ) ) {
 			    // initialise the member variable
 			 logger.info("option uid called with "+cmd.getOptionValue( "guid" ));
@@ -323,9 +323,9 @@ public class Dispatch {
 			}
 		 else {
 			 guid=UUID.randomUUID().toString();
-		 }	
-		 
-		 
+		 }
+
+
 		 if( cmd.hasOption( "s" ) ) {
 			 //Fix 1337 support relative path
 			 File  lv_file = new File(cmd.getOptionValue( "s" ));
@@ -337,19 +337,19 @@ public class Dispatch {
 		 }
 		 if( cmd.hasOption( "g" ) ) {
 			//Fix 1337 support relative path
-			 File  lv_file = new File(cmd.getOptionValue( "g" ));			 
+			 File  lv_file = new File(cmd.getOptionValue( "g" ));
 			    grammar=lv_file.getAbsolutePath();
 		 }
 		 else if( cmd.hasOption( "m" ) ) {
 			//Fix 1337 support relative path
 			 File  lv_file = new File(cmd.getOptionValue( "m" ));
 			    model=lv_file.getAbsolutePath();
-		 }		 
+		 }
 		 else {
 			 displayError("Option m is missing");
 			 System.exit(1);
 		 }
-		 
+
 		 if( cmd.hasOption( "local" ) ) {
 			 logger.info("Using local system");
 			   type=LOCAL;
@@ -360,20 +360,20 @@ public class Dispatch {
 			    type=SGE;
 			    jobmngr = (JobManager) new SGEJobManager();
 		 }
-		 if( cmd.hasOption( "dna" ) ) {			 
-			    format=1;			
+		 if( cmd.hasOption( "dna" ) ) {
+			    format=1;
 		 }
-		 if( cmd.hasOption( "rna" ) ) {			 
-			    format=2;			
-		 }		
-		 if( cmd.hasOption( "protein" ) ) {			 
-			    format=3;			
-		 }				 
-		 
+		 if( cmd.hasOption( "rna" ) ) {
+			    format=2;
+		 }
+		 if( cmd.hasOption( "protein" ) ) {
+			    format=3;
+		 }
+
 		 if( cmd.hasOption( "conf" ) ) {
 			//Fix 1337 support relative path
 			 File  lv_file = new File(cmd.getOptionValue( "conf" ));
-			 configFile=lv_file.getAbsolutePath();			
+			 configFile=lv_file.getAbsolutePath();
 		 }
 		 else {
 				if(System.getProperty("logol.conf")!=null) {
@@ -384,31 +384,31 @@ public class Dispatch {
 					displayError("conf option is missing");
 					System.exit(1);
 				}
-			 
+
 		 }
-		 
+
 		 if( cmd.hasOption( "contig" ) ) {
 			    isContig=true;;
 		 }
 
 		 if( cmd.hasOption( "noclean" ) ) {
 			    noclean=true;;
-		 }		 
+		 }
 		 if( cmd.hasOption( "email" ) ) {
 			    email=cmd.getOptionValue( "email" );
 		 }
-		 
+
 		 if( cmd.hasOption( "max" ) ) {
 			 maxSolutions=Integer.valueOf(cmd.getOptionValue( "max" ));
 		 }
-		 
-		 
+
+
 		 if( cmd.hasOption( "maxmatchsize" ) ) {
 			    // initialise the member variable
 			 logger.info("option max match size called with "+cmd.getOptionValue( "maxmatchsize" ));
 			 maxMatchSize=Integer.valueOf(cmd.getOptionValue( "maxmatchsize"));
 		}
-		 
+
 		 if( cmd.hasOption( "noclean" ) ) {
 			    // initialise the member variable
 			 logger.info("option noclean called");
@@ -419,75 +419,75 @@ public class Dispatch {
 			    // initialise the member variable
 			 logger.info("option out called with "+cmd.getOptionValue("out"));
 			 zipFileName = cmd.getOptionValue("out");
-			}	
-		 
+			}
+
 		 if(cmd.hasOption("forcesplit")) {
 			 forceSplittingUsage = true;
 		 }
-		 
+
 		 if( cmd.hasOption( "fasta" ) ) {
 			    convert2fasta=true;;
 		 }
-		 
+
 		 if( cmd.hasOption( "gff" ) ) {
 			    convert2gff=true;;
 		 }
-		 
+
 		 try {
 			config = new PropertiesConfiguration(configFile);
 		} catch (ConfigurationException e) {
 			displayError(e.getMessage());
 			System.exit(1);
 		}
-		 
-		 
+
+
 		 workDir = config.getString("workingDir");
 		 /*
 		  * If working on a cluster, a shared directory with nodes is required to share the sequence.
 		  * This directory must be defined with result.dir
 		  */
 		 if(config.getString("dir.result")!=null)  { workDir = config.getString("dir.result"); }
-		 
+
 		 //installDir = config.getString("installPath");
 			String path = System.getProperty("logol.install");
-			if(path!=null)  { 
+			if(path!=null)  {
 				installDir = path;
 			}
 			else {
 				installDir=".";
 			}
-		
-			
+
+
 		 if(config.containsKey("nbProcessor")) {
 			nbproc = config.getInt("nbProcessor");
 			}
-				
+
 		if(config.containsKey("nbJobs")) {
 			nbjobs = config.getInt("nbJobs");
 			}
-		 
+
 		if(config.containsKey("mail.from")) {
 			fromMail = config.getString("mail.from");
-			}	
-		
+			}
+
 		minSplitSize =config.getInt("minSplitSize");
-		
+
 		// if not in command line use default
 		if(!cmd.hasOption( "maxmatchsize" )) {
 		maxMatchSize = config.getInt("maxMatchSize");
 		}
-		 
+
 		// If maxSolutions not set in command-line
 		// FIX 1320
 		if(maxSolutions==0 && config.containsKey("maxSolutions")) {
 			maxSolutions = config.getInt("maxSolutions");
 		}
-		
-		 
+
+
 		 for(int j=0;j<args.length;j++) {
 			 jobArgs+=" "+args[j];
 		 }
-		 
+
 		 jobmngr.setJobArgs(jobArgs);
 		 jobmngr.setInstallPath(installDir);
 
@@ -496,7 +496,7 @@ public class Dispatch {
 		 if(!wDir.exists()) {
 			 displayError("Error, directory "+workDir+" does not exist");
 		 }
-		 		
+
 		 try {
 			int lv_nbmodel = 1;
 			if (!forceSplittingUsage) {
@@ -513,7 +513,7 @@ public class Dispatch {
 			displayError(e.getMessage());
 			System.exit(1);
 		}
-		 
+
 	}
 
 	private static void displayError(String message) {
@@ -521,7 +521,7 @@ public class Dispatch {
 	    	  //send an email with file result
 	    	  // Use a email.tpl and replace a tag with file name (http:// or path)
 	 	     //Set the host smtp address
-	    	 
+
 	 	     Properties props = new Properties();
 	 	     props.put("mail.smtp.host", config.getString("smtp.host"));
 	 	     logger.debug("send mail to host "+config.getString("smtp.host"));
@@ -543,7 +543,7 @@ public class Dispatch {
 	 	     	}
 	 	     	File bfile =  new File(bank);
 	 	     	if(bfile!=null) subject += " vs "+ bfile.getName();
-	 	     	subject += " is over"; 
+	 	     	subject += " is over";
 				LogolUtils.sendMail(props, new String[] {email}, subject, message, fromMail);
 			} catch (MessagingException e) {
 				logger.error("Result email could not be sent: "+e.getMessage());
@@ -552,7 +552,7 @@ public class Dispatch {
 	      else {
 	    	  System.err.println(message);
 	      }
-		
+
 	}
 
 	/**
@@ -561,8 +561,8 @@ public class Dispatch {
 	 * @throws BioException
 	 * @throws IOException
 	 */
-	private static void splitBankandExecute(int nbModels) throws BioException, IOException {		
-		
+	private static void splitBankandExecute(int nbModels) throws BioException, IOException {
+
 		BufferedReader br = new BufferedReader(new FileReader(bank));
 
 	      /*
@@ -574,44 +574,44 @@ public class Dispatch {
 	      RichSequenceIterator iter =  null;
 	      /*
 	      switch (format) {
-	      case 1: { 
+	      case 1: {
 	    	  iter= (RichSequenceIterator)IOTools.readFastaDNA(br,null);
 	    	  break;
 	      }
-	      case 2: { 
+	      case 2: {
 	    	  iter= (RichSequenceIterator)IOTools.readFastaRNA(br,null);
 	    	  break;
 	      }
-	      case 3: { 
+	      case 3: {
 	    	  iter= (RichSequenceIterator)IOTools.readFastaProtein(br,null);
 	    	  break;
-	      }	      
+	      }
 	      }
 	      */
 	      //Fix1660
 	      iter = (RichSequenceIterator) org.irisa.genouest.logol.utils.MySequenceIterator.readFasta(br);
-	 
-	      
+
+
 	      File bFile = new File(bank);
 	      String bankName = bFile.getName();
-	      
+
 	      String uid = null;
-	      
+
 	      int seqID=1;
-	      
+
 	      Vector<String> outFiles = new Vector<String>();
 	      Vector<String> xmlFiles = new Vector<String>();
-	      
+
 	      HashMap<String,Vector<SubSequence>> sequenceFiles = new HashMap<String,Vector<SubSequence>>();
 	      Vector<SubSequence> subSequences = null;
-	      
+
 	      int offset=0;
-	      
+
 	      while(iter.hasNext()){
 	    	  subSequences = new Vector<SubSequence>();
 	    	  uid = UUID.randomUUID().toString();
 	    	  String outFileName = workDir+System.getProperty(FILESEPARATORPROPERTY)+bankName+"."+uid;
-	    	 	    	 
+
 	    	  Sequence seq = iter.nextSequence();
 	    	  //Check if can be splitted, if yes add all sub seq to subSequences
 	    	  Integer[][] subData = LogolUtils.splitSequence(seq.length(), nbjobs, minSplitSize, maxMatchSize, nbModels);
@@ -619,7 +619,7 @@ public class Dispatch {
 	    	  for(int sub=0;sub<subData.length;sub++) {
 	    	  SubSequence subSeq = new SubSequence();
 	    	  subSeq.name=outFileName;
-	    	  
+
 	    	  subSeq.sequenceID=seqID;
 	    	  subSeq.wholeLength=seq.length();
 	    	  subSeq.offset=offset;
@@ -628,25 +628,25 @@ public class Dispatch {
 	    	  logger.debug("Add subsequence to job list: length "+subSeq.wholeLength+", start: "+subSeq.start+", length: "+subSeq.length);
 	    	  subSequences.add(subSeq);
 	    	  }
-	    	  
-	    	  
+
+
 	    	  logger.info("Add sequence for treatment: "+outFileName);
 	    	  logger.debug("Add subsequences, size: "+subSequences.size());
 	    	  sequenceFiles.put(outFileName,subSequences);
-	    	  
+
 	    	  if(isContig) {
 	    		  offset+=seq.length();
 	    	  }
-	    	  
+
 	    	  seqID++;
 	      }
-	      
-	      
+
+
 	      String seqArgs = "";
 
 	      Set<String> files = sequenceFiles.keySet();
 	      Iterator<String> itFiles = files.iterator();
-	      
+
 	      while(itFiles.hasNext()){
 	    	  String seqName = (String) itFiles.next();
 	    	  logger.debug("seqName: "+seqName);
@@ -657,23 +657,23 @@ public class Dispatch {
 	    	  String outFileName = seq.name;
 	    	  String xmlFileName = outFileName+"."+seq.sequenceID+".xml";
 	    	  int length = seq.wholeLength;
-	    	  
+
 	    	  logger.debug("write file "+outFileName);
 	    	  seqArgs="";
-	    	  
+
 	    	  // 1 name per sequence
 	    	  outFiles.add(outFileName);
 	    	  xmlFiles.add(xmlFileName);
 	    	  //now add job info
-	    	  
+
 	    	  if(isContig) {
 	    		  logger.info("Add offset to sequence : "+seq.offset);
-	    		  seqArgs = "-offset "+seq.offset; 	    		  	    		  
+	    		  seqArgs = "-offset "+seq.offset;
 	    	  }
-	    	  seqArgs += " -sequenceID "+seq.sequenceID;	    	  
-	    	
+	    	  seqArgs += " -sequenceID "+seq.sequenceID;
+
 	    	  logger.info("Args: "+seqArgs);
-	    	  
+
 	    	  if(seqs.size()==1) {
 	    		  jobmngr.addJob(outFileName,xmlFileName,seqArgs);
 	    	  }else {
@@ -684,39 +684,39 @@ public class Dispatch {
 		    			  subArgs+=" -end "+(sub.start+sub.length);
 		    			  logger.info("Subsequence Args: "+subArgs);
 		    			  logger.debug("Temp xml file generated: "+xmlFileName+"."+job);
-		    			  jobmngr.addJob(outFileName,xmlFileName+"."+job,seqArgs+subArgs);		    		  
+		    			  jobmngr.addJob(outFileName,xmlFileName+"."+job,seqArgs+subArgs);
 		    	  }
 	    	  }
-	    	  
-	    	  
+
+
 	      }
-	    
+
 	      String nativeSpecifications=null;
 	      if(config.getString("drm.queue")!=null && !config.getString("drm.queue").equals("")) {
 	    	  nativeSpecifications=config.getString("drm.queue");
 	      }
-	      
+
 	      //TODO modify to do run only no wait. jobmngr should manage max parallel jobs for sge case.
 	      jobmngr.runJobs(nativeSpecifications);
 
-	      
-	      jobmngr.waitForJobsOver();
-	      
-	    
-	      
 
-	      //Merge files requiring it ( subSequences.length>1 )	      
+	      jobmngr.waitForJobsOver();
+
+
+
+
+	      //Merge files requiring it ( subSequences.length>1 )
 	      files = sequenceFiles.keySet();
-	      itFiles = files.iterator();	      
+	      itFiles = files.iterator();
 	      while(itFiles.hasNext()){
 	    	  String seqName = (String) itFiles.next();
-	    	  Vector<SubSequence> seqs = (Vector<SubSequence>) sequenceFiles.get(seqName);	    	  
+	    	  Vector<SubSequence> seqs = (Vector<SubSequence>) sequenceFiles.get(seqName);
 	    	  // If size > 1, then needs to be merged
 	    	  if(seqs.size()>1) {
-	    		  mergeSubSequenceResults(seqs);	    		  
+	    		  mergeSubSequenceResults(seqs);
 	    	  }
 	      }
-	      
+
 	      // Fix 1271
 	      // Parse error files for all sequences
 	      itFiles = files.iterator();
@@ -734,23 +734,28 @@ public class Dispatch {
 	    		  for(int j=0;j<seqs.size();j++) {
 	    	    	  SubSequence sub = seqs.get(j);
 	    	    	  String err= readErrorFile(sub.name+"."+sub.sequenceID+".xml."+j);
-	    	    	  if (err.length()>0) { errMsg = sub.name+"."+sub.sequenceID+".xml."+j+":\n"+err+"\n";}
+	    	    	  if (err.length()>0) { errMsg += sub.name+"."+sub.sequenceID+".xml."+j+":\n"+err+"\n";}
 	    		  }
 	    	  }
 	      }
-	      
+
+              if(errMsg.length()>0) {
+                 logger.error("Sub processes errors: \n"+errMsg);
+              }
+
+
 	      String zipFile = null;
-	      
+
 	      if(zipFileName!=null) {
 	    	  // If output path specified
 	    	  zipFile = zipFileName;
-	    	  } 
-	      else { 
-	    	  // Else get unique file
-	    	  zipFile = workDir+System.getProperty(FILESEPARATORPROPERTY)+bankName+"."+guid+".zip"; 
 	    	  }
-	      
-	      
+	      else {
+	    	  // Else get unique file
+	    	  zipFile = workDir+System.getProperty(FILESEPARATORPROPERTY)+bankName+"."+guid+".zip";
+	    	  }
+
+
 	      if(convert2fasta || convert2gff) {
 	    	 String fastafile="";
 	    	 String gfffile="";
@@ -771,21 +776,21 @@ public class Dispatch {
 			        	gc = new GFFConverter();
 			        	gc.convert2GFF(file2convert, gfffile);
 			        	xmlFiles.add(gfffile);
-			        }		        			       
+			        }
 		        }
-	    	  
+
 	      }
 
 	      LogolUtils.countMatches(xmlFiles);
-	      
+
 	      LogolUtils.zipFiles(xmlFiles, zipFile);
 	      logger.info("Result file is available at: "+zipFile);
-	      
+
 	      if(email!=null) {
 	    	  //send an email with file result
 	    	  // Use a email.tpl and replace a tag with file name (http:// or path)
 	 	     //Set the host smtp address
-	    	 
+
 	 	     Properties props = new Properties();
 	 	     props.put("mail.smtp.host", config.getString("smtp.host"));
 	 	     logger.debug("send mail to host "+config.getString("smtp.host"));
@@ -804,7 +809,7 @@ public class Dispatch {
 	 	     if(errMsg.length()>0) {
 	 	    	 message += "ERRORS: \n"+errMsg;
 	 	     }
-	 	     
+
 	 	     	logger.debug("Send message: "+message);
 	 	     	String subject = "[LogolMatch] Job request ";
 	 	     	if(model==null) {
@@ -814,7 +819,7 @@ public class Dispatch {
 	 	     		subject += new File(model).getName();
 	 	     	}
 	 	     	subject += " vs "+ new File(bank).getName();
-	 	     	subject += " is over"; 
+	 	     	subject += " is over";
 				LogolUtils.sendMail(props, new String[] {email}, subject, message, fromMail);
 			} catch (MessagingException e) {
 				logger.error("Result email could not be sent: "+e.getMessage());
@@ -822,19 +827,23 @@ public class Dispatch {
 				logger.error("Result email could not be sent: "+e.getMessage());
 			}
 	      }
-	      
+
 	      // Now clean intermediate files
 	      for(int i=0;i<outFiles.size();i++) {
 	    	  File tmpFile = new File((String)outFiles.get(i));
-	    	  tmpFile.delete();	    	  
+	    	  tmpFile.delete();
 	      }
 	      if(!noclean) {
-	      for(int i=0;i<xmlFiles.size();i++) {
-	    	  File tmpFile = new File((String)xmlFiles.get(i));
-	    	  tmpFile.delete();	    	  
-	      }	      
+		      for(int i=0;i<xmlFiles.size();i++) {
+		    	  File tmpFile = new File((String)xmlFiles.get(i));
+		    	  tmpFile.delete();
+				  File f = new File((String)xmlFiles.get(i)+".err");
+				  if(f.exists()) { f.delete(); }
+				  f = new File((String)xmlFiles.get(i)+".out");
+				  if(f.exists()) { f.delete(); }
+			  }
 	      }
-	      
+
 	}
 
 
@@ -842,7 +851,7 @@ public class Dispatch {
 		String err = "";
 		logger.debug("Analysing error file "+seqName+".err");
 		File input = new File(seqName+".err");
-		if(input.exists()) {			
+		if(input.exists()) {
 			try {
 				String line=null;
 				 BufferedReader bufRead = new BufferedReader(new FileReader(input));
@@ -862,8 +871,8 @@ public class Dispatch {
 	private static void mergeSubSequenceResults(Vector<SubSequence> seqs) {
 	      /**
 	       * Apply stylesheet to merge files and update id to get a unique among all sub results
-	       */			
-		
+	       */
+
 	      String inFile=null;
 	      //String outFile=null;
 	      String xsltFile=installDir+System.getProperty(FILESEPARATORPROPERTY)+"prolog"+System.getProperty(FILESEPARATORPROPERTY)+"logol.merge.xsl";
@@ -871,7 +880,7 @@ public class Dispatch {
 	      String mergeFileName  = seq.name+"."+seq.sequenceID+".xml";
 	      logger.info("Merge sub sequences to file "+mergeFileName);
 	      File mergeFile = new File(mergeFileName);
-	      
+
 	      PrintWriter mergeOutputStream=null;
 		try {
 			mergeOutputStream = new PrintWriter(mergeFile);
@@ -881,19 +890,19 @@ public class Dispatch {
 		      //mergeOutputStream.println("<fastaHeader>"+seq.header+"</fastaHeader>");
 		      mergeOutputStream.println("<sequenceBegin>"+seq.offset+"</sequenceBegin>");
 		      mergeOutputStream.println("<sequenceEnd>"+(seq.offset+seq.wholeLength)+"</sequenceEnd>");
-		      
+
 		      // Include original grammar or model in result
 		      FileReader mFile=null;
 		      String mHeader = null;
 		      if(model!=null) {
 		    	  mFile = new FileReader(model);
-		    	  mHeader = "model";	      
+		    	  mHeader = "model";
 		      }
 		      else {
 		    	  mFile = new FileReader(grammar);
-			      mHeader = "grammar";	    	  
+			      mHeader = "grammar";
 		      }
-		      
+
 		      BufferedReader bufRead = new BufferedReader(mFile);
 		      String line = "";
 		      String mContent="";
@@ -901,27 +910,27 @@ public class Dispatch {
 		    	  mContent+=line+"\n";
 		      }
 		      mFile.close();
-		      
-		      
+
+
 		      mergeOutputStream.println("<"+mHeader+">"+Base64.encode(mContent.getBytes())+"</"+mHeader+">");
-		      
-		      
-		      
+
+
+
 		} catch (FileNotFoundException e1) {
 			logger.error("Error while applying stylesheet in postprocess: "+e1.getMessage());
 		} catch (IOException e) {
 			logger.error("Error while applying stylesheet in postprocess: "+e.getMessage());
-		}	  
-	
+		}
+
 	      int countMergedResults = 0;
-	      
-	     
+
+
 	      for(int i=0;i<seqs.size();i++) {
 	    	  logger.debug("transform xml result file with stylesheet");
 	    	  SubSequence sub = seqs.get(i);
 	    	  inFile = sub.name+"."+sub.sequenceID+".xml."+i;
 	    	  logger.debug("merging "+inFile);
-	    	
+
 	    	  try {
 	    		  if(countMergedResults<maxSolutions) {
 	    			  countMergedResults += transformXSLT(inFile,xsltFile,mergeOutputStream,String.valueOf(i));
@@ -933,7 +942,7 @@ public class Dispatch {
 			} catch (TransformerException e) {
 				logger.error("Error while applying stylesheet in postprocess: "+e.getMessage());
 			} catch (ParserConfigurationException e) {
-				logger.error("Error while applying stylesheet in postprocess: "+e.getMessage());				
+				logger.error("Error while applying stylesheet in postprocess: "+e.getMessage());
 			} catch (SAXException e) {
 				logger.error("Error while applying stylesheet in postprocess: "+e.getMessage());
 			} catch (IOException e) {
@@ -942,7 +951,7 @@ public class Dispatch {
 
 	      }
 	      mergeOutputStream.println("</sequences>");
-	      
+
 	      // Now remove intermediate xml result files
 	      for(int i=0;i<seqs.size();i++) {
 	    	  logger.debug("remove temp result files");
@@ -953,11 +962,11 @@ public class Dispatch {
 	    		  in.delete();
 	    	  }
 	      }
-	      
-	      
+
+
 	      mergeOutputStream.close();
 	        logger.debug("file transformed and renamed");
-		
+
 	}
 
 	/**
@@ -977,21 +986,21 @@ public class Dispatch {
 		in.close();
 		return res;
 	}
-	
-	
-	
+
+
+
 	/**
 	 * Transform generated xml file in a more appropriate format for analyse (reorder variables according to position...)
 	 * @param inFile generated xml file
 	 * @param xsltFile stylesheet to use
 	 * @param mergeOutputStream new xml file
 	 * @throws TransformerException
-	 * @throws ParserConfigurationException 
-	 * @throws IOException 
-	 * @throws SAXException 
+	 * @throws ParserConfigurationException
+	 * @throws IOException
+	 * @throws SAXException
 	 */
 	//private static void transformXSLT(String inFile, String xsltFile, String outFile,String id) throws FileNotFoundException, TransformerException {
-		
+
 	private static int transformXSLT(String inFile, String xsltFile,
 				PrintWriter mergeOutputStream, String id) throws TransformerException, ParserConfigurationException, SAXException, IOException {
 
@@ -1008,23 +1017,23 @@ public class Dispatch {
 		String lv_filename = lv_file.getName();
 
 		transformer.setParameter("fileid", id);
-		// 3. Use the Transformer to transform an XML Source and send the output to a Result object.	
+		// 3. Use the Transformer to transform an XML Source and send the output to a Result object.
 		transformer.transform
-	    (new javax.xml.transform.stream.StreamSource(inFile), 
-	     new javax.xml.transform.stream.StreamResult( mergeOutputStream));		
-		
+	    (new javax.xml.transform.stream.StreamSource(inFile),
+	     new javax.xml.transform.stream.StreamResult( mergeOutputStream));
+
 	    mergeOutputStream.flush();
-		
+
 		DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
 		Document document = builder.parse(new File(inFile));
 		NodeList matchNodeList =  XPathAPI.selectNodeList(document,"/sequences/match");
 		if(matchNodeList==null) {
 			return 0;
-		}		
+		}
 		return matchNodeList.getLength();
-		
-		
+
+
 	}
-	
-	
+
+
 }
